@@ -7,6 +7,7 @@
 @Email   :   bj.yan.pa@qq.com
 """
 
-__all__ = ["opts"]
+__all__ = ["opts", "Logger"]
 
 from .opt import opts
+from .logger import Logger
\ No newline at end of file
