@@ -15,40 +15,22 @@ import numpy as np
 
 from fedhf.core import build_server, build_client
 
-from fedhf.component import Logger, build_sampler
+from fedhf.component import build_sampler
 from fedhf.dataset import ClientDataset, build_dataset
 
-from .base_coordinator import BaseCoordinator
+from .base_coordinator import SimulatedBaseCoordinator
 
 
-class SimulatedAsyncCoordinator(BaseCoordinator):
+class SimulatedAsyncCoordinator(SimulatedBaseCoordinator):
     """Simulated Coordinator
         In simulated scheme, the data and model belong to coordinator and there is no need communicator.
         Also, there is no need to instantiate every client.
     """
     def __init__(self, args) -> None:
-        self.args = args
+        super(SimulatedAsyncCoordinator, self).__init__(args)
 
     def prepare(self) -> None:
-        self.dataset = build_dataset(self.args.dataset)(self.args)
-        self.sampler = build_sampler(self.args.sampler)(self.args)
-
-        if self.args.test:
-            # reduce data for test
-            self.data = [
-                ClientDataset(self.dataset.trainset,
-                              range(i * self.args.batch_size, (i + 1) * self.args.batch_size))
-                for i in range(self.args.num_clients)
-            ]
-        else:
-            self.data = self.sampler.sample(self.dataset.trainset)
-
-        self.client_list = [i for i in range(self.args.num_clients)]
-        self.server = build_server('simulated')(self.args)
-        # self.client = build_client('simulated')(self.args)
-
-        self.logger = Logger(self.args)
-
+        super(SimulatedAsyncCoordinator, self).prepare()
         self._model_queue = []
 
     def main(self) -> None:
@@ -63,7 +45,7 @@ class SimulatedAsyncCoordinator(BaseCoordinator):
                 self.logger.info(f'Round {i} Selected clients: {selected_clients}')
 
                 for client_id in selected_clients:
-                    client = build_client('simulated')(self.args, client_id)
+                    client = build_client(self.args.deploy_mode)(self.args, client_id)
 
                     staleness = np.random.randint(
                         low=1,
@@ -113,22 +95,7 @@ class SimulatedAsyncCoordinator(BaseCoordinator):
             self.logger.info(f'Interrupted by user.')
 
     def finish(self) -> None:
-        self.server.model.save()
-
-        try:
-            for client_id in self.client_list:
-                client = build_client('simulated')(self.args, client_id)
-                result = client.evaluate(data=self.data[client_id], model=self.server.model)
-                self.logger.info(f'Client {client_id} result: {result}')
-
-            result = self.server.evaluate(self.dataset.testset)
-            self.logger.info(f'Server result: {result}')
-            self.logger.info(
-                f'Final server model version: {self.server.model.get_model_version()}')
-        except KeyboardInterrupt:
-            self.logger.info(f'Interrupted by user.')
-
-        self.logger.info(f'All finished.')
+        super(SimulatedAsyncCoordinator, self).finish()
 
     def run(self) -> None:
         self.prepare()
